@@ -9,8 +9,6 @@ Maintainer  : public@hjwylde.com
 Options and handler for the choose subcommand.
 -}
 
-{-# LANGUAGE OverloadedStrings #-}
-
 module Werewolf.Command.Choose (
     -- * Options
     Options(..),
@@ -29,12 +27,14 @@ import Control.Monad.Writer
 import Data.Text (Text)
 
 import Game.Werewolf
+import Game.Werewolf.Command
 import Game.Werewolf.Command.Hunter    as Hunter
 import Game.Werewolf.Command.Orphan    as Orphan
 import Game.Werewolf.Command.Scapegoat as Scapegoat
+import Game.Werewolf.Engine
+import Game.Werewolf.Message.Error
 
-import Werewolf.Game
-import Werewolf.Messages
+import Werewolf.System
 
 data Options = Options
     { args :: [Text]
