@@ -9,8 +9,6 @@ Maintainer  : public@hjwylde.com
 Handler for the heal subcommand.
 -}
 
-{-# LANGUAGE OverloadedStrings #-}
-
 module Werewolf.Command.Heal (
     -- * Handle
     handle,
@@ -25,10 +23,12 @@ import Control.Monad.Writer
 import Data.Text (Text)
 
 import Game.Werewolf
+import Game.Werewolf.Command
 import Game.Werewolf.Command.Witch
+import Game.Werewolf.Engine
+import Game.Werewolf.Message.Error
 
-import Werewolf.Game
-import Werewolf.Messages
+import Werewolf.System
 
 handle :: (MonadIO m, MonadRandom m) => Text -> Text -> m ()
 handle callerName tag = do
