@@ -23,10 +23,12 @@ import Control.Monad.Writer
 import Data.Text (Text)
 
 import Game.Werewolf
+import Game.Werewolf.Command
 import Game.Werewolf.Command.Global
+import Game.Werewolf.Engine
+import Game.Werewolf.Message.Error
 
-import Werewolf.Game
-import Werewolf.Messages
+import Werewolf.System
 
 handle :: (MonadIO m, MonadRandom m) => Text -> Text -> m ()
 handle callerName tag = do
