@@ -22,10 +22,11 @@ import Control.Monad.Writer
 import Data.Text (Text)
 
 import Game.Werewolf
+import Game.Werewolf.Command
 import Game.Werewolf.Command.Status
+import Game.Werewolf.Message.Error
 
-import Werewolf.Game
-import Werewolf.Messages
+import Werewolf.System
 
 handle :: MonadIO m => Text -> Text -> m ()
 handle callerName tag = do
