@@ -19,9 +19,7 @@ import Control.Monad.Except
 import Data.Text (Text)
 
 import Game.Werewolf
-
-import Werewolf.Messages
-import Werewolf.Version
+import Game.Werewolf.Message.Command
 
 handle :: MonadIO m => Text -> m ()
-handle callerName = exitWith success { messages = [engineVersionMessage callerName version] }
+handle callerName = exitWith success { messages = [engineVersionMessage callerName] }
