@@ -9,6 +9,7 @@ Maintainer  : public@hjwylde.com
 Optparse utilities.
 -}
 
+{-# LANGUAGE CPP               #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 module Werewolf.Options (
@@ -19,14 +20,23 @@ module Werewolf.Options (
     werewolfPrefs, werewolfInfo, werewolf,
 ) where
 
+import Control.Lens
+
+#if MIN_VERSION_optparse_applicative(0,13,0)
+import Data.Monoid
+#endif
 import           Data.Text    (Text)
 import qualified Data.Text    as T
 import           Data.Version (showVersion)
 
+import Game.Werewolf.Variant
+
+import Options.Applicative
+
 import qualified Werewolf.Command.Boot      as Boot
 import qualified Werewolf.Command.Choose    as Choose
 import qualified Werewolf.Command.Circle    as Circle
-import qualified Werewolf.Command.End       as End
+import qualified Werewolf.Command.Divine    as Divine
 import qualified Werewolf.Command.Help      as Help
 import qualified Werewolf.Command.Interpret as Interpret
 import qualified Werewolf.Command.Poison    as Poison
@@ -36,8 +46,6 @@ import qualified Werewolf.Command.Start     as Start
 import qualified Werewolf.Command.Vote      as Vote
 import qualified Werewolf.Version           as This
 
-import Options.Applicative
-
 data Options = Options
     { optCaller  :: Text
     , optTag     :: Text
@@ -48,7 +56,8 @@ data Command
     = Boot Boot.Options
     | Choose Choose.Options
     | Circle Circle.Options
-    | End End.Options
+    | Divine Divine.Options
+    | End
     | Heal
     | Help Help.Options
     | Interpret Interpret.Options
@@ -57,9 +66,11 @@ data Command
     | Poison Poison.Options
     | Protect Protect.Options
     | Quit
+    | Raise
     | See See.Options
     | Start Start.Options
     | Status
+    | Unvote
     | Version
     | Vote Vote.Options
     deriving (Eq, Show)
@@ -67,7 +78,11 @@ data Command
 -- | The default preferences.
 --   Limits the help output to 100 columns.
 werewolfPrefs :: ParserPrefs
+#if MIN_VERSION_optparse_applicative(0,13,0)
+werewolfPrefs = prefs $ columns 100 <> showHelpOnEmpty
+#else
 werewolfPrefs = prefs $ columns 100
+#endif
 
 -- | An optparse parser of a werewolf command.
 werewolfInfo :: ParserInfo Options
@@ -96,6 +111,7 @@ werewolf = Options
         [ command "boot"        $ info (helper <*> boot)        (fullDesc <> progDesc "Vote to boot a player")
         , command "choose"      $ info (helper <*> choose)      (fullDesc <> progDesc "Choose an allegiance or player(s)")
         , command "circle"      $ info (helper <*> circle)      (fullDesc <> progDesc "Get the game circle")
+        , command "divine"      $ info (helper <*> divine)      (fullDesc <> progDesc "Divine a player's role")
         , command "end"         $ info (helper <*> end)         (fullDesc <> progDesc "End the current game")
         , command "heal"        $ info (helper <*> heal)        (fullDesc <> progDesc "Heal the devoured player")
         , command "help"        $ info (helper <*> help_)       (fullDesc <> progDesc "Help documents")
@@ -105,9 +121,11 @@ werewolf = Options
         , command "poison"      $ info (helper <*> poison)      (fullDesc <> progDesc "Poison a player")
         , command "protect"     $ info (helper <*> protect)     (fullDesc <> progDesc "Protect a player")
         , command "quit"        $ info (helper <*> quit)        (fullDesc <> progDesc "Quit the current game")
+        , command "raise"       $ info (helper <*> raise)       (fullDesc <> progDesc "Raise the dead as Zombies")
         , command "see"         $ info (helper <*> see)         (fullDesc <> progDesc "See a player's allegiance")
         , command "start"       $ info (helper <*> start)       (fullDesc <> progDesc "Start a new game")
         , command "status"      $ info (helper <*> status)      (fullDesc <> progDesc "Get the status of the current game")
+        , command "unvote"      $ info (helper <*> unvote)      (fullDesc <> progDesc "Rescind a vote")
         , command "version"     $ info (helper <*> version)     (fullDesc <> progDesc "Show this engine's version")
         , command "vote"        $ info (helper <*> vote)        (fullDesc <> progDesc "Vote against a player")
         ])
@@ -125,12 +143,11 @@ circle = Circle . Circle.Options
         , help "Include dead players"
         ])
 
+divine :: Parser Command
+divine = Divine . Divine.Options <$> playerArgument
+
 end :: Parser Command
-end = End . End.Options
-    <$> switch (mconcat
-        [ long "force", short 'f'
-        , help "Force the game to end"
-        ])
+end = pure End
 
 heal :: Parser Command
 heal = pure Heal
@@ -141,6 +158,7 @@ help_ = Help . Help.Options
         [ command "commands"    $ info (Help.Commands <$> allOption)    (fullDesc <> progDesc "Print the in-game commands")
         , command "roles"       $ info (Help.Roles <$> allOption)       (fullDesc <> progDesc "Print the roles and their descriptions")
         , command "rules"       $ info (Help.Rules <$> allOption)       (fullDesc <> progDesc "Print the game rules")
+        , command "variants"    $ info (Help.Variants <$> allOption)    (fullDesc <> progDesc "Print the variants and their descriptions")
         ])
     where
         allOption = switch $ long "all" <> short 'a'
@@ -164,15 +182,19 @@ protect = Protect . Protect.Options <$> playerArgument
 quit :: Parser Command
 quit = pure Quit
 
+raise :: Parser Command
+raise = pure Raise
+
 see :: Parser Command
 see = See . See.Options <$> playerArgument
 
 start :: Parser Command
 start = fmap Start $ Start.Options
     <$> (extraRolesOption <|> randomExtraRolesOption)
-    <*> switch (mconcat
-        [ long "include-seer"
-        , help "Always include the Seer"
+    <*> fmap T.pack (strOption $ mconcat [
+        long "variant", short 'v', metavar "VARIANT",
+        value standardVariantTag, showDefaultWith $ const standardVariantTag,
+        help "Specify the game variant"
         ])
     <*> some (T.pack <$> strArgument (metavar "PLAYER..."))
     where
@@ -187,9 +209,14 @@ start = fmap Start $ Start.Options
             , help "Use random extra roles"
             ]
 
+        standardVariantTag = T.unpack $ standardVariant ^. tag
+
 status :: Parser Command
 status = pure Status
 
+unvote :: Parser Command
+unvote = pure Unvote
+
 version :: Parser Command
 version = pure Version
 
