@@ -8,24 +8,22 @@ Maintainer  : public@hjwylde.com
 
 Re-exports all of the public modules under /Game.Werewolf/. These are:
 
-* "Game.Werewolf.Command"
-* "Game.Werewolf.Engine"
 * "Game.Werewolf.Game"
 * "Game.Werewolf.Player"
 * "Game.Werewolf.Response"
 * "Game.Werewolf.Role"
+* "Game.Werewolf.Variant"
 
-N.B., where clashes are found between "Game.Werewolf.Player" and "Game.Werewolf.Role", the
-"Game.Werewolf.Player" functions are preferred.
+N.B., where clashes are found between "Game.Werewolf.Player", "Game.Werewolf.Role" and
+"Game.Werewolf.Variant", the "Game.Werewolf.Player" functions are preferred.
 -}
 
 module Game.Werewolf (
     module Werewolf
 ) where
 
-import Game.Werewolf.Command  as Werewolf
-import Game.Werewolf.Engine   as Werewolf
 import Game.Werewolf.Game     as Werewolf
 import Game.Werewolf.Player   as Werewolf
 import Game.Werewolf.Response as Werewolf
-import Game.Werewolf.Role     as Werewolf hiding (name)
+import Game.Werewolf.Role     as Werewolf hiding (activity, name)
+import Game.Werewolf.Variant  as Werewolf hiding (description, name, tag)
